K1K2computes the differences between
both univariate $K$-functions (i.e. $Ki(r)-Kj(r)$) as well as the differences between
the univariate and the bivariate $K$-function (i.e. $Ki(r)-Kij(r)$ and $Kj(r)-Kij(r)$).
It also computes simulation envelopes to test that that the observed differences are within the
range expected asuming the random labelling hypothesis.K1K2(X, i, j, nsim = 99, nrank = 1, r = NULL,
correction = "isotropic")ppp format of nsim simulated values.
A rank of 1 means that the minimum and maximum simulated values will be used.fv.object, essentially a data.frame with the following items:K1-K2, K1-K12 and K2-K12).K1K2 uses $K^*ij(r)$, the combined estimator of Lotwick and Silverman (a weigthed mean of
$Kij(r)$ and $Kji(r)$) as computed by Kmulti.ls.data(Helianthemum)
cosa12 <- K1K2(Helianthemum, j="deadpl", i="survpl", r=seq(0,200,le=201),
nsim=999, nrank=1, correction="isotropic")plot(cosa12$k1k2, lty=c(2, 1, 2), col=c(2, 1, 2), xlim=c(0, 200),
main= "survival- death")
plot(cosa12$k1k12, lty=c(2, 1, 2), col=c(2, 1, 2), xlim=c(0, 200),
main="segregation of surviving seedlings")
plot(cosa12$k2k12, lty=c(2, 1, 2), col=c(2, 1, 2), xlim=c(0, 200),
main= "segregation of dying seedlings")Run the code above in your browser using DataLab