syrjala0(coords, var1, var2, nsim, R=FALSE)
syrjala(coords = NULL, var1 = NULL, var2 = NULL, nperm = 999)
syrjala.test(ppp1, ppp2, nsim = 999)
## S3 method for class 'syrjala.test':
plot(x, coline=1, ...)
## S3 method for class 'ecespa.syrjala':
plot(x, ...)data.frame with `$x` and `$y` components.ppp format of spatstat,
representing the values of some parameter measured on the corresponding sampling locations.ppp format of spatstat,
representing the values of some other parameter measured on the same locations than ppp1.syrjala.test' or 'ecespa.syrjala' resulting from syrjala or syrjala.test, respectively.hist.syrjala or syrjala0 (with the argument R=FALSE) return an object of class 'syrjala.test'.
Functions syrjala.test or syrjala0 (with the argument R=TRUE) return an object of class 'ecespa.syrjala'.
In Both cases, the result is a list with the following elements:nperm+1 simulated $psi$'s statistics (including cvm.obs).nperm+1 simulated $psi$'s statistics (including ks.obs).nsim simulated $psi$'s statistics.ppp's as the supporting data format, this kind of data are not spatial point patterns.
They cannot be analysed with the usual tools employed for marked point patterns.data(syr1); data(syr2); data(syr3)
plot(syrjala.test(syr1, syr2, nsim=999))
plot(syrjala.test(syr1, syr3, nsim=999))
coords <- data.frame(x=syr1$x, y=syr1$y); var1<- syr1$marks; var2<- syr2$marks
syrjala(coords, var1, var2, 9999)
syrjala0(coords, var1, var2, 9999)
syrjala0(coords, var1, var2, 999, R=TRUE)
coords <- expand.grid(x=1:10,y=1:10)
var1 <- runif(100)
var2 <- runif(100)
syrjala(coords, var1, var2, 9999)Run the code above in your browser using DataLab